/*
 * This file is part of Mable+, a program for checking MAB data for errors.
 *
 * Copyright (C) 2008, 2011-2012 Kooperativer Bibliotheksverbund
 * Berlin-Brandenburg (KOBV) <http://www.kobv.de>,
 * im Konrad-Zuse-Zentrum für Informationstechnik
 * Berlin (ZIB) <http://www.zib.de>, Takustr. 7, D-14195 Berlin-Dahlem
 * Author(s) Jens Schwidder, <schwidder(at)zib.de>,
 *           Pascal-Nicolas Becker, <becker(at)zib.de>
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <http://www.gnu.org/licenses/>.
 */
package de.kobv.mable.mab2.modules;

import de.kobv.mable.mab.MabFeldDefinition;
import de.kobv.mable.mab.MabSatz;
import de.kobv.mable.mab.extension.DatasetError;
import de.kobv.mable.mab.extension.ErrorType;

/**
 * Prüft für einen Datensatztyp, ob mindestens eines von zwei Feldern vorhanden ist.
 *
 * @author Jens Schwidder <schwidder(at)zib.de>
 */
public class AtLeastOneField extends AbstractMabCheck {

    private String zweiteKategorie;

    private ErrorType errorType;

    @Override
    public void process(final MabSatz satz) {
        if (satz.getSatzkennung().getTyp() == getSatzTyp()) {
            if (!satz.isFeldPresent(getKategorie()) && !satz.isFeldPresent(getZweiteKategorie())) {
                // Keine der beiden Kategorien gefunden
                getErrorStatistics().addError(new DatasetError(getErrorType(), satz.getId()));
            }
        }
    }

    public String getZweiteKategorie() {
        return zweiteKategorie;
    }

    public void setZweiteKategorie(final String kategorie) {
        this.zweiteKategorie = kategorie;
    }

    public void setZweiteFeldnummer(int feldnummer) {
        setZweiteKategorie(MabFeldDefinition.getFeldnummerString(feldnummer));
    }

    public ErrorType getErrorType() {
        if (errorType == null) {
            errorType = new AtLeastOneFieldErrorType(getSatzTypAsString(), getKategorie(), getZweiteKategorie(),
                    getErrorMessageKey(), getErrorCode());
        }

        return errorType;
    }

}
