/*
 * This file is part of Mable+, a program for checking MAB data for errors.
 *
 * Copyright (C) 2008, 2011-2012 Kooperativer Bibliotheksverbund
 * Berlin-Brandenburg (KOBV) <http://www.kobv.de>,
 * im Konrad-Zuse-Zentrum für Informationstechnik
 * Berlin (ZIB) <http://www.zib.de>, Takustr. 7, D-14195 Berlin-Dahlem
 * Author(s) Jens Schwidder, <schwidder(at)zib.de>,
 *           Pascal-Nicolas Becker, <becker(at)zib.de>
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <http://www.gnu.org/licenses/>.
 */
package de.kobv.mable.mab2.modules;

import de.kobv.mable.mab.extension.ErrorType;
import org.apache.commons.lang.builder.HashCodeBuilder;

/**
 * Created with IntelliJ IDEA.
 * User: jens
 * Date: 8/24/12
 * Time: 2:21 PM
 * To change this template use File | Settings | File Templates.
 *
 * @author Jens Schwidder <schwidder(at)zib.de>
 *
 * TODO create FieldCountError class with count
 * TODO indikator?
 * TODO subtypes (0, too few, too many)
 */
public class FieldCountErrorType extends ErrorType {

    private int errorHash;

    private String kategorie;

    private String indikator;

    public FieldCountErrorType(final String kategorie) {
        this.kategorie = kategorie;
    }

    public FieldCountErrorType(final String kategorie, final String indikator) {
        this.kategorie = kategorie;
        this.indikator = indikator;
    }

    public String getKategorie() {
        return kategorie;
    }

    public String getIndikator() {
        return indikator;
    }

    public String getMessage() {
        String msg = super.getMessage();
        if (msg == null) {
            String feldname = getFeldname(kategorie);
            if (feldname != null) {
                feldname = " (" + feldname + ")";
            }
            else {
                feldname = "";
            }

            if (indikator == null) {
                msg = "Häufigkeit von Feld "  + kategorie + feldname + " entspricht nicht dem Wiederholfaktor.";
            }
            else {
                msg = "Häufigkeit von Feld "  + kategorie + indikator + feldname
                        + " entspricht nicht dem Wiederholfaktor.";
            }
        }
        return msg;
    }

    public String toString() {
        if (indikator != null) {
            return super.toString() + "[" + kategorie + indikator + "]";
        }
        else {
            return super.toString() + "[" + kategorie + "]";
        }
    }

    public int getHash() {
        if (errorHash == 0) {
            errorHash = new HashCodeBuilder()
                    .append(getClass())
                    .append(kategorie)
                    .append(indikator)
                    .toHashCode();
        }
        return errorHash;
    }

}
