/*
 * This file is part of Mable+, a program for checking MAB data for errors.
 *
 * Copyright (C) 2008, 2011-2012 Kooperativer Bibliotheksverbund
 * Berlin-Brandenburg (KOBV) <http://www.kobv.de>,
 * im Konrad-Zuse-Zentrum für Informationstechnik
 * Berlin (ZIB) <http://www.zib.de>, Takustr. 7, D-14195 Berlin-Dahlem
 * Author(s) Jens Schwidder, <schwidder(at)zib.de>,
 *           Pascal-Nicolas Becker, <becker(at)zib.de>
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <http://www.gnu.org/licenses/>.
 */
package de.kobv.mable.mab2.modules;

import de.kobv.mable.mab.extension.DatasetError;
import de.kobv.mable.mab.extension.ErrorType;
import org.apache.commons.lang.builder.HashCodeBuilder;

/**
 * Fehlerklasse für fehlende Referenzen.
 *
 * @author Jens Schwidder <schwidder(at)zib.de>
 */
public class ReferenceErrorType extends ErrorType {

    private String kategorie;

    private String zielSatztyp;

    public ReferenceErrorType(String kategorie, String zielSatztyp) {
        this(kategorie, zielSatztyp, null, 0);
    }

    public ReferenceErrorType(String kategorie, String zielSatztyp, String message, int errorCode) {
        super(message, errorCode);
        this.kategorie = kategorie;
        this.zielSatztyp = zielSatztyp;
    }

    public String getKategorie() {
        return kategorie;
    }

    public String getZielSatztyp() {
        return zielSatztyp;
    }

    @Override
    public String getMessage() {
        String msg = super.getMessage();
        if (msg == null) {
            msg = String.format("In Feld %1$s referenzierter Satz wurde nicht gefunden.", kategorie);
        }
        return msg;
    }

    @Override
    public int getHash() {
        return new HashCodeBuilder()
                .append(getClass())
                .append(kategorie)
                .append(zielSatztyp)
                .toHashCode();
    }

    public String toString() {
        return super.toString() + "[" + kategorie + ", " + zielSatztyp + "]";
    }




}
